#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
import transaction

# import interfaces
from hypatia.interfaces import ICatalog
from pyams_content.shared.common.interfaces import IWfSharedContent
from pyams_utils.interfaces.site import ISiteGenerations
from zope.intid.interfaces import IIntIds
from zope.site.interfaces import INewLocalSite

# import packages
from pyams_utils.container import find_objects_providing
from pyams_utils.registry import utility_config, set_local_registry, get_utility
from pyams_utils.site import check_required_utilities, site_factory
from pyramid.events import subscriber
from zope.intid import IntIds


REQUIRED_UTILITIES = ((IIntIds, '', IntIds, 'Internal IDs'),)


@subscriber(INewLocalSite)
def handle_new_local_site(event):
    """Create a new IntIds when a site is created"""
    site = event.manager.__parent__
    check_required_utilities(site, REQUIRED_UTILITIES)


@utility_config(name='PyAMS base', provides=ISiteGenerations)
class BaseGenerationsChecker(object):
    """PyAMS base generations checker"""

    generation = 1

    def evolve(self, site, current=None):
        """Check for required utilities"""
        check_required_utilities(site, REQUIRED_UTILITIES)


def site_index(request):
    """Index all site contents in internal catalog"""
    application = site_factory(request)
    if application is not None:
        try:
            set_local_registry(application.getSiteManager())
            catalog = get_utility(ICatalog)
            intids = get_utility(IIntIds)
            for document in find_objects_providing(application, IWfSharedContent):
                print("Indexing: {0!r}".format(document))
                catalog.reindex_doc(intids.register(document), document)
        finally:
            set_local_registry(None)
        transaction.commit()
    return application
